Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(528)

Unified Diff: mojo/devtools/common/devtoolslib/shell.py

Issue 1269863004: Support mapping multiple local paths under the same url prefix. (Closed) Base URL: git@github.com:domokit/mojo.git@master
Patch Set: Fix typos in tests. Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « mojo/devtools/common/devtoolslib/linux_shell.py ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: mojo/devtools/common/devtoolslib/shell.py
diff --git a/mojo/devtools/common/devtoolslib/shell.py b/mojo/devtools/common/devtoolslib/shell.py
index 0b542a7f598ac17d22660b0c319c01ca79639e25..c142611f15803584bd5e9e647a48decc5f4815e4 100644
--- a/mojo/devtools/common/devtoolslib/shell.py
+++ b/mojo/devtools/common/devtoolslib/shell.py
@@ -30,14 +30,15 @@ class Shell(object):
call returns immediately.
Args:
- mappings: List of tuples (prefix, local_base_path) mapping URLs that start
- with |prefix| to local directory at |local_base_path|. The prefixes
- should skip the leading slash. The first matching prefix will be used
- each time.
+ mappings: List of tuples (prefix, local_base_path_list) mapping URLs that
+ start with |prefix| to one or more local directories enumerated in
+ |local_base_path_list|. The prefixes should skip the leading slash.
+ The first matching prefix and the first location that contains the
+ requested file will be used each time.
port: port at which the server will be available to the shell
Returns:
- The url that the shell can use to access the content of |local_dir_path|.
+ The url that the shell can use to access the server.
"""
raise NotImplementedError()
« no previous file with comments | « mojo/devtools/common/devtoolslib/linux_shell.py ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698